.. _install:

Installing Aesara
=================

The latest release of Aesara can be installed from Pypi using `pip`:

.. code-block:: bash

    pip install aesara


Or via conda-force:

.. code-block:: bash

    conda install -c conda-forge aesara


The current development branch of Aesara can be installed from GitHub using `pip`:


.. code-block:: bash

    pip install git+https://github.com/aesara-devs/aesara


To use the Numba and JAX backend you will need to install these libraries in addition to Aesara. Please refer to `Numba's installation instructions <https://numba.readthedocs.io/en/stable/user/installing.html>`__ and `JAX's installation instructions  <https://github.com/google/jax#installation>`__ respectively.
